@@ -12,10 +12,10 @@ from ecomplexity.coicog import calc_coi_cog
 # IO-PS framework value chain mapping
 def iops(tradedata, valuechain=None, countrycode=710, tradedigit=6, statanorm=False):
     """ IO-PS calculation function that writes the results to .xls and .csv
-        Args:
+        Arguments:
             tradedata: pandas dataframe containing raw CEPII-BACI trade data.
             valuechain: .csv of the value chain the IO-PS will map.
-                columns - 'tier', 'category', 'trade code'
+                columns - 'tier', 'category', ' HS trade code'
                 default - None
             countrycode: integer indicating which country the IO-PS will map.
                 default - 710
